/* -
 *
 * Author: Damien Masson
 * Copyright University of Lille / Inria
 *
 * http://ns.inria.fr/mjolnir/whichfingers/
 *
 * This software may be used and distributed according to the terms of
 * the GNU General Public License version 2 or any later version.
 *
 */

#include "mainwindow.h"
#include "ui_mainwindow.h"
#include <QDebug>
#include <QKeyEvent>

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow),
    device(0x2341, 0x8036) {
    ui->setupUi(this);
    ui->buttonGroup->setExclusive(false);

    for (int i = 0; i < 5; ++i) {
        fingerKey[i] = -1;
    }
}

/*
 * Finger identification : look for the piezo with the highest value between t-32 and t-8
 * The timewindow could be different depending on the device your using
 */
int MainWindow::getFingerUsed() {
    double highestVal = 0;
    double fingerUsed = 0;
    for (int j = 0; j < 5; ++j) {
        QQueue<double> values = device.getPiezoValues(j);
        for (int i = 8; i < 32; ++i) {
            double val = values.at(values.size() - i);
            if (val > highestVal) {
                highestVal = val;
                fingerUsed = j;
            }
        }
    }

    return fingerUsed;
}

void MainWindow::keyPressEvent(QKeyEvent * event) {
    if (!event->isAutoRepeat()) {
        fingerKey[getFingerUsed()] = event->key();
        updateCheckboxes();
    }
}

void MainWindow::keyReleaseEvent(QKeyEvent * event) {
    for (int i = 0; i < 5; ++i) {
        if (fingerKey[i] == event->key()) {
            fingerKey[i] = -1;
        }
    }
    updateCheckboxes();
}

void MainWindow::updateCheckboxes() {
    for (int i = 0; i < 5; ++i) {
        ui->buttonGroup->buttons().at(i)->setChecked(fingerKey[i] > 0);
    }
}

MainWindow::~MainWindow() {
    delete ui;
}
