/* -
 *
 * Author: Damien Masson
 * Copyright University of Lille / Inria
 *
 * http://ns.inria.fr/mjolnir/whichfingers/
 *
 * This software may be used and distributed according to the terms of
 * the GNU General Public License version 2 or any later version.
 *
 */

#include "mainwindow.h"
#include "ui_mainwindow.h"
#include <QDebug>
#include <QKeyEvent>

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow) {
    ui->setupUi(this);
    ui->buttonGroup->setExclusive(false);

    for (unsigned int i = 0; i < sizeof(fingerKey) / sizeof(int); ++i) {
        fingerKey[i] = -1;
    }
    connect(&whichFingers, SIGNAL(fingerIdentified(int)), SLOT(onFingerIdentified(int)));
}

void MainWindow::onFingerIdentified(int fingerId) {
    // For this example we are only handling one hand so if it's the right hand we should substract 5 to have ids between 0 and 5
    fingerKey[fingerId - 5] = whichFingers.getFingers()[fingerId].getTouchId();
    updateCheckboxes();
}

void MainWindow::keyPressEvent(QKeyEvent * event) {
    if (!event->isAutoRepeat()) {
        // As it's wireless, we just inform WhichFingers that a finger pressed a device (could be anything, keyboard, touchpad...)
        // Then the function "onFingerIdentified" will be called when the finger will be identified (should take ~9ms, depending on your wifi connection)
        whichFingers.devicePressed(0, event->key());
    }
}

void MainWindow::keyReleaseEvent(QKeyEvent * event) {
    whichFingers.deviceReleased(0, event->key());

    for (int i = 0; i < 5; ++i) {
        if (fingerKey[i] == event->key()) {
            fingerKey[i] = -1;
        }
    }
    updateCheckboxes();
}

void MainWindow::updateCheckboxes() {
    for (int i = 0; i < 5; ++i) {
        ui->buttonGroup->buttons().at(i)->setChecked(fingerKey[i] > 0);
    }
}

MainWindow::~MainWindow() {
    delete ui;
}
