/* -
 *
 * Author: Damien Masson
 * Copyright University of Lille / Inria
 *
 * http://ns.inria.fr/mjolnir/whichfingers/
 *
 * This software may be used and distributed according to the terms of
 * the GNU General Public License version 2 or any later version.
 *
 */

#ifndef WHICHFINGERS_H
#define WHICHFINGERS_H

#include <QObject>
#include <QHash>
#include <QHostAddress>
#include <QSignalMapper>
#include "finger.h"

class QTcpServer;
class QTcpSocket;
class QUdpSocket;

typedef struct _finger_request {
    unsigned char id;
    unsigned char is_calibration;
} finger_request;

typedef struct _finger_response {
    unsigned char maxValues[5];
    unsigned char id;
    //unsigned char lastSpikeIdx;
    //unsigned char lastSpikeTime;
    //int idx;
    //unsigned char handSide;
    //unsigned char data[5][100];
} finger_response;

typedef struct _handshake_packet {
    unsigned char handSide;
} handshake_packet;


typedef struct _finger_to_identify {
    Finger finger;
    int nbResponseToReceive;
    unsigned char packetId;
    QHash<QHostAddress, finger_response> responses;
} finger_to_identify;


#define LEFT_HAND 0
#define RIGHT_HAND 1

class WhichFingers : public QObject
{
    Q_OBJECT
public:
    WhichFingers();
    ~WhichFingers();

    void devicePressed(int deviceId, int touchId);
    void deviceReleased(int deviceId, int touchId);
    void getPiezoValues(long long int timestamp, unsigned char values[5]);
    void calibrateOnPress(unsigned char fingerUsed);
    void resetCalibration();
    Finger* getFingers();

private slots:
    void acceptConnection();
    void receiveTcpData();
    void receiveUdpData();
    void clientDisonnected();

signals:
    void fingerIdentified(int fingerId);
    void handsConnected();

private:
    QHash<QHostAddress, unsigned char> hostHandSide;

    QTcpServer *tcpServer;
    QUdpSocket *udpServer;
    QUdpSocket *udpSocket;

    QTcpSocket* handClient[2];

    qint64 startTimestamp;
    qint64 lastRequestTimestamp;

    finger_response lastResponse;

    Finger fingers[10];

    QList<finger_to_identify> fingersToIdentify;

    unsigned char curPacketId;

    int sendRequest(long long int timestamp, unsigned char packetId);
    void identifyFinger(finger_to_identify fingerToId);
    void sendCalibrationRequest(int hand, unsigned char finger);

};

#endif // WHICHFINGERS_H
